
<p align="center">
    <strong style="font-size: 32px;">LLAMATOR</strong>  
    <br>
    <span style="font-size: 20px;">Red teaming framework</span>
</p>

---

## Description

Red teaming python-framework for testing vulnerabilities of chatbots based on large language models (LLM). Supports testing of Russian-language RAG systems.

## Install

```bash
pip install llamator
```
## Documentation

Documentation Link: https://romiconez.github.io/llamator/

## Examples

 * [RAG Chatbot testing via API (RU)](/examples/llamator-api.ipynb)
 * [Gandalf bot testing via Selenium (RU)](/examples/llamator-selenium.ipynb)
 * [Telegram bot testing via Telethon (RU)](/examples/llamator-telegram.ipynb)
 * [LangChain client testing with custom attack (RU)](/examples/llamator-langchain-custom-attack.ipynb)

## Architecture

![architecture](/assets/architecture.png)

## License

This project is licensed under the terms of the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International license. See the LICENSE file for details.

[![Creative Commons License](https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png)](http://creativecommons.org/licenses/by-nc-sa/4.0/)